============
 References
============

.. toctree::
   :maxdepth: 2
              
.. automodule:: py_deps.deps
   :members:
   :show-inheritance:
   :inherited-members:

.. automodule:: py_deps.graph
   :members:
   :show-inheritance:
   :inherited-members:
